@@ -1,5 +1,5 @@
 #!/bin/sh
 
 mkdir -p autotools
-autoreconf -fi && ./configure $@
+autoreconf -fi && ./configure "$@"
 
