@@ -31,8 +31,11 @@ struct conf_option {
 	} value;
 };
 
+extern const struct conf_option *ConfOptionByName(const char *name);
+
 extern void swloadconf(void);
 extern void swsaveconf(void);
-extern void setconfig(void);          // config menu
+
+extern const struct menu options_menu;
 
 #endif
