@@ -18,9 +18,9 @@ extern void swinitlevel(void);
 extern void swrestart(void);
 extern void initdisp(bool reset);
 extern void initgrnd(void);
-extern void initcomp(OBJECTS *obp);
-extern void initplyr(OBJECTS *obp);
-extern OBJECTS *initpln(OBJECTS *obp);
+extern void initcomp(OBJECTS *obp, const original_ob_t *orig_ob);
+extern void initplyr(OBJECTS *obp, const original_ob_t *orig_ob);
+extern OBJECTS *initpln(OBJECTS *obp, const original_ob_t *orig_ob);
 extern void initshot(OBJECTS *obop, OBJECTS *targ);
 extern void initbomb(OBJECTS *obop);
 extern void initmiss(OBJECTS *obop);
